# Gridlock - a collection of grid-based strategy games
# Copyright (c) 2009 Brian Nenninger (brian@dozingcatsoftware.com)
# Gridlock comes with ABSOLUTELY NO WARRANTY, and is released under version 3 of the GNU GPL.

import wx
import wx.xrc

import Preferences

class Controller(object):
    def __init__(self, controller):
        import os.path
        self.game_controller = controller
        self.res = wx.xrc.XmlResource(os.path.join('xrc', 'pygrid_chat.xrc'))
        self.frame = self.res.LoadFrame(None, 'main_frame')
        self.frame.Bind(wx.EVT_CLOSE, self.hide_window)
        
        self.transcript_field = wx.xrc.XRCCTRL(self.frame, 'transcript_field')
        self.message_field = wx.xrc.XRCCTRL(self.frame, 'message_field')
        
        self.message_field.Bind(wx.EVT_TEXT_ENTER, self.send_message)
        wx.xrc.XRCCTRL(self.frame, 'send_button').Bind(wx.EVT_BUTTON, self.send_message)

    def show_window(self):
        self.frame.Show()
        self.frame.Raise()
        self.message_field.SetFocus()

    def hide_window(self, event=None):
        self.frame.Hide()
        
    def is_window_visible(self):
        return self.frame.IsShown()

    def send_message(self, event):
        msg = self.message_field.GetValue()
        if msg:
            self.game_controller.broadcast_chat_message(msg)
            self.append_chat_message(Preferences.prefs.get_username(), msg)
            self.message_field.SetValue("")
            
    def append_chat_message(self, username, msg):
        s = username + ": " + msg + "\n"
        self.transcript_field.SetValue(self.transcript_field.GetValue() + s)
        